import extra_data


class epix100Ctrl():
    def __init__(
        self,
        run_dc: extra_data.DataCollection,
        ctrl_src: str,
        instrument_src: str,
    ):
        """Read epix100 parameters to use later while quering CALCAT.
        :param run_dir: EXtra-data RunDirectory DataCollection object.
        :param ctrl_src: CONTROL source for accessing slow data.
        :param instrument_src: INSTRUMENT source for accessing fast data.
        """
        self.run_dc = run_dc
        self.ctrl_src = ctrl_src
        self.instrument_src = instrument_src

    def get_integration_time(self):
        return self.run_dc[
            self.ctrl_src, 'expTime.value'].as_single_value(reduce_by='first')

    def get_temprature(self):
        """Get temperature value from CONTROL.
        Temprature is stored in Celsius/100 units.
        Therefore, we are dividing by 100 and
        there is an absolute tolerance of 100.
        atol=100 is a 1 degree variation tolerance.
        """
        # data.backTemp shape evolved from (n_trains,) to (n_trains, 1)
        return self.run_dc[
            self.instrument_src, 'data.backTemp'].as_single_value(
                reduce_by='mean', atol=100).item() / 100
